@@ -155,7 +155,9 @@ class Changelog(object):
         """
         Возвращает текущую версию Changelog
         """
-        version_list = [item for item in list(self.versions)[1:] if not item.version.is_prerelease]
+        versions = \
+            list(self.versions)[1:] if self.versions[0].version.base_version == 'unreleased' else list(self.versions)
+        version_list = [item for item in versions if not item.version.is_prerelease]
         return self.unreleased if len(version_list) == 0 else max(version_list)
 
     @property
@@ -190,22 +192,23 @@ class Changelog(object):
                         return True
         return False
 
-    def save(self, path: str = None):
+    def save(self, path: str = None, add_unreleased: bool = False):
         """
         Сохраняет changelog в файл. Если указан путь то по нему, если нет - то по адресу открытия
         :param path: Путь для нового сохранения
+        :param add_unreleased" добавление пустой версии UNRELEASED
         """
         path = path if path else self.path
         if path:
             with open(path, 'w', encoding='UTF8') as fp:
-                fp.write(self.text())
+                fp.write(self.text(add_unreleased=add_unreleased))
 
-    def text(self):
+    def text(self, add_unreleased=True):
         """
         Возвращает текстовое представление changelog
         """
         result = f'#{self.name.upper()}\n'
-        result += self.versions.text()
+        result += self.versions.text(add_unreleased=add_unreleased)
         return result.strip() + '\n'
 
     def sync(self, other: "Changelog"):
