@@ -12,12 +12,12 @@ class VersionCollection(list):
     def sorted(self):
         return sorted(self, reverse=True)
 
-    def text(self):
+    def text(self, add_unreleased=True):
         result = ''
         for index, item in enumerate(self.sorted()):
             if index == 0 and item.version.public.lower() != 'unreleased':
-                result += VersionBlock(version='unreleased').text()
-            result += item.text()
+                result += VersionBlock(version='unreleased').text(add_unreleased=add_unreleased)
+            result += item.text() if item.has_changes() or add_unreleased else ''
         return result.strip()
 
     def get_by_name(self, version_name):
@@ -71,16 +71,22 @@ class VersionBlock(object):
         changes = [item.change_type.priority for item in self.change_blocks.values() if item.changes]
         return min(changes) if changes else None
 
-    def text(self):
+    def text(self, add_unreleased=False):
         """
         Возвращает приведенный к тексту элемент
         """
         result = f"## [{self.version.public.upper()}]"
         result = result + f' - {self.date.strftime("%Y-%m-%d")}\n' if self.date else result + '\n'
         for item in self.change_blocks:
-            result += self.change_blocks[item].text()
+            if self.change_blocks[item] or add_unreleased:
+                result += self.change_blocks[item].text()
         if self.version.public.lower() == 'unreleased':
             result += '\n---\n\n'
         else:
             result += '\n'
         return result
+
+    def has_changes(self):
+        for change_block in self.change_blocks:
+            if self.change_blocks[change_block].changes:
+                return True
\ No newline at end of file
